#!/bin/sh
# Copyright (c) 2006 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Authors: Bill Peck, Arjan van de Ven, Paul Sutherland

if [ -z "$OUTPUTFILE" ]; then
        OUTPUTFILE=`mktemp /tmp/tmp.XXXXXX`
fi

if [ -z "$TESTPATH" ]; then
   TESTVERSION="developer"
else
   if [ -e "$TESTPATH/runtest.sh" ]; then
      TESTVERSION=$(rpm -qf $TESTPATH/runtest.sh)
   fi
fi

if [ -z "$HOSTNAME" ]; then
   HOSTNAME=$(hostname)
fi 

if [ -z "$ARCH" ]; then
        ARCH=`uname -i`
fi

#Set to "+no_avc_check" in order to not report AVC messages to rhts
if [ -z "$AVC_ERROR" ]; then
    export AVC_ERROR=`mktemp /tmp/tmp.XXXXXX`
    touch $AVC_ERROR
fi

touch $OUTPUTFILE

# this file is for sourcing in rhts test scripts

function report_result {
	rhts-report-result $1 $2 $OUTPUTFILE $3
}

#
# Do a startup test of a program
# Assumption is that the program will wait for user input so we'll
# kill it after 15 seconds
#
function startup_test {

	wasrunning=`pidof Xvfb`

	if [ "0$wasrunning" -eq "0" ]; then
        	Xvfb :1 -screen 0 1600x1200x24 -fbdir /tmp &
		sleep 3
        	export DISPLAY=:1
	fi
        
	ulimit -c unlimited
        rm -rf core*
        
        export MALLOC_PERTURB_=$(($RANDOM % 256))
        
	rhts-timed-test.sh 15 $1 $2 $3 $4 &> $OUTPUTFILE

	grep -q "Gtk-CRITICAL" $OUTPUTFILE
	if [ "$?" -eq "0" ]; then
		result=WARN
	fi                          
	
	which=$(which $1)
	if [ "$?" -eq "0" ]; then
		file $which | grep -q ELF
		if [ "$?" -eq "0" ]; then
			ldd $which | grep -q "=> not found"
			if [ "$?" -eq "0" ]; then
				ldd $which >> $OUTPUTFILE
				result=FAIL
			fi
		fi
	else
		result=FAIL
		echo "$1 is not found" >> $OUTPUTFILE
	fi
                          
	value=`ls core* | wc -l`
	if [ "$value" -ne "0" ]; then
 		result=FAIL
	fi
	
        ulimit -c 0
                          
        if [ "0$wasrunning" -eq "0" ]; then
        	kill `pidof Xvfb`
        fi
}


